@@ -1,3 +1,4 @@
+from ._tdigest_mixin import TDigestCommandsMixin
 from ._topk_mixin import TopkCommandsMixin  # noqa: F401
 
 try:
@@ -23,13 +24,23 @@ except ImportError as e:
         raise e
 
 
-    class BFCommandsMixin:  # noqa: E303
+    class BFCommandsMixin:  # type: ignore # noqa: E303
         pass
 
 
-    class CFCommandsMixin:  # noqa: E303
+    class CFCommandsMixin:  # type: ignore # noqa: E303
         pass
 
 
-    class CMSCommandsMixin:  # noqa: E303
+    class CMSCommandsMixin:  # type: ignore # noqa: E303
         pass
+
+__all__ = [
+    "TopkCommandsMixin",
+    "JSONCommandsMixin",
+    "JSONObject",
+    "BFCommandsMixin",
+    "CFCommandsMixin",
+    "CMSCommandsMixin",
+    "TDigestCommandsMixin",
+]
